@@ -46,7 +46,7 @@ class OvsPlugin(plugin.PluginBase):
 
     If given a VIFBridge, then it will create connect the VM via
     a regular Linux bridge device to allow security group rules to
-    be applied to VM traiffic.
+    be applied to VM traffic.
     """
 
     NIC_NAME_LEN = 14
@@ -196,12 +196,11 @@ class OvsPlugin(plugin.PluginBase):
         return profile.datapath_type
 
     def _plug_vhostuser(self, vif, instance_info):
-        self.ovsdb.ensure_ovs_bridge(
-            vif.network.bridge, self._get_vif_datapath_type(
-                vif, datapath=constants.OVS_DATAPATH_NETDEV))
         vif_name = OvsPlugin.gen_port_name(
             constants.OVS_VHOSTUSER_PREFIX, vif.id)
         args = {}
+        args['datapath_type'] = self._get_vif_datapath_type(vif,
+                datapath=constants.OVS_DATAPATH_NETDEV)
         if vif.mode == "client":
             args['interface_type'] = \
                 constants.OVS_VHOSTUSER_INTERFACE_TYPE
@@ -291,8 +290,8 @@ class OvsPlugin(plugin.PluginBase):
         # was written it was understood by me that libvirt would not
         # modify ovs if the port exists but in fact it deletes and
         # recreates the port. This both undoes the effort to resolve
-        # bug #1734320 and intoduces other issues for neutron.
-        # this comment will be removed when we actully fix #1734320 in
+        # bug #1734320 and introduces other issues for neutron.
+        # this comment will be removed when we actually fix #1734320 in
         # all cases.
 
         # NOTE(hamdyk): As a WA to the above note, one can use
